@@ -1563,11 +1563,11 @@ def concatenate(seq, axis=0, allow_unknown_chunksizes=False):
         if any(map(np.isnan, seq2[0].shape)):
             raise ValueError(
                 "Tried to concatenate arrays with unknown"
-                " shape %s.\n\nTwo solutions:\n"
+                f" shape {seq2[0].shape}.\n\nTwo solutions:\n"
                 "  1. Force concatenation pass"
                 " allow_unknown_chunksizes=True.\n"
                 "  2. Compute shapes with "
-                "[x.compute_chunk_sizes() for x in seq]" % str(seq2[0].shape)
+                "[x.compute_chunk_sizes() for x in seq]"
             )
         raise ValueError("Shapes do not align: %s", [x.shape for x in seq2])
 
