@@ -26,7 +26,7 @@ def _sanitize_index_element(ind):
     if isinstance(ind, Number):
         ind2 = int(ind)
         if ind2 != ind:
-            raise IndexError("Bad index.  Must be integer-like: %s" % ind)
+            raise IndexError(f"Bad index.  Must be integer-like: {ind}")
         else:
             return ind2
     elif ind is None:
@@ -92,7 +92,7 @@ def sanitize_index(ind):
         else:
             check_int = np.isclose(index_array, int_index)
             first_err = index_array.ravel()[np.flatnonzero(~check_int)[0]]
-            raise IndexError("Bad index.  Must be integer-like: %s" % first_err)
+            raise IndexError(f"Bad index.  Must be integer-like: {first_err}")
     else:
         raise TypeError("Invalid index type", type(ind), ind)
 
@@ -694,9 +694,9 @@ def _expander(where):
             if i in where:
                 left.append("val, ")
             else:
-                left.append("seq[%d], " % j)
+                left.append(f"seq[{j}], ")
                 j += 1
-        right = "seq[%d:]" % j
+        right = f"seq[{j}:]"
         left = "".join(left)
         decl = decl.format(**locals())
         ns = {}
@@ -736,7 +736,7 @@ def new_blockdim(dim_shape, lengths, index):
         for i, slc in pairs
     ]
     if isinstance(index, slice) and index.step and index.step < 0:
-        slices = slices[::-1]
+        slices.reverse()
     return [int(math.ceil((1.0 * slc.stop - slc.start) / slc.step)) for slc in slices]
 
 
