@@ -12,7 +12,7 @@ np = pytest.importorskip("numpy")
 import itertools
 
 import dask.array as da
-import dask.config as config
+from dask import config
 from dask.array.numpy_compat import ComplexWarning
 from dask.array.utils import assert_eq, same_keys
 from dask.core import get_deps
@@ -144,6 +144,17 @@ def test_reductions_1D(dtype):
     reduction_1d_test(da.nanmax, a, np.nanmax, x, False)
 
 
+def test_reductions_1D_datetime():
+    x = np.arange(5).astype("datetime64[ns]")
+    a = da.from_array(x, chunks=(2,))
+    reduction_1d_test(da.min, a, np.min, x, False)
+    reduction_1d_test(da.max, a, np.max, x, False)
+    reduction_1d_test(da.any, a, np.any, x, False)
+    reduction_1d_test(da.all, a, np.all, x, False)
+    reduction_1d_test(da.nanmin, a, np.nanmin, x, False)
+    reduction_1d_test(da.nanmax, a, np.nanmax, x, False)
+
+
 @pytest.mark.parametrize("dtype", ["f4", "c8"])
 @pytest.mark.parametrize(
     "x", [np.array([np.inf, np.nan, -np.inf, 2]), np.array([np.nan, np.nan, 3, 2])]
@@ -257,6 +268,17 @@ def test_reductions_2D(dtype):
         reduction_2d_test(da.nanprod, a, np.nanprod, x)
 
 
+def test_reductions_2D_datetime():
+    x = np.arange(1, 122).reshape(11, 11).astype("datetime64[ns]")
+    a = da.from_array(x, chunks=(4, 4))
+    reduction_2d_test(da.min, a, np.min, x, False)
+    reduction_2d_test(da.max, a, np.max, x, False)
+    reduction_2d_test(da.any, a, np.any, x, False)
+    reduction_2d_test(da.all, a, np.all, x, False)
+    reduction_2d_test(da.nanmin, a, np.nanmin, x, False)
+    reduction_2d_test(da.nanmax, a, np.nanmax, x, False)
+
+
 @pytest.mark.parametrize(
     ["dfunc", "func"],
     [
@@ -664,6 +686,24 @@ def test_array_cumreduction_dtype(func, method, target_dtype):
     assert_eq(a_r, d_r)
 
 
+@pytest.mark.parametrize("ufunc", ["add", "multiply", "maximum"])
+@pytest.mark.parametrize("target_dtype", [None, int, float])
+def test_array_cumreduction_ufunc(ufunc, target_dtype):
+    ufunc_obj = getattr(np, ufunc)
+    accumulate = ufunc_obj.accumulate
+    identity = ufunc_obj.identity
+
+    a = np.linspace(0, 1, num=10, dtype=float)
+    d = da.from_array(a)
+
+    cumreduction = da.reductions.cumreduction
+
+    a_r = accumulate(a, dtype=target_dtype)
+    d_r = cumreduction(accumulate, ufunc_obj, identity, d, dtype=target_dtype)
+
+    assert_eq(a_r, d_r)
+
+
 @pytest.mark.parametrize("func", [np.cumsum, np.cumprod])
 def test_array_cumreduction_out(func):
     x = da.ones((10, 10), chunks=(4, 4))
@@ -1002,7 +1042,6 @@ def test_quantile(rechunk, q, axis):
 
 @pytest.mark.parametrize("func", [da.quantile, da.nanquantile, da.nanpercentile])
 def test_quantile_func_family_with_axis_none(func):
-
     # Check that these functions raise a NotImplementedError
     # when axis=None and more than one chunk is present
     # along at least one dimension
