@@ -15,8 +15,8 @@ from dask.delayed import delayed
 np = pytest.importorskip("numpy")
 
 import dask.array as da
-from dask.array.numpy_compat import NUMPY_GE_200, AxisError
-from dask.array.utils import assert_eq, same_keys
+from dask.array.numpy_compat import NUMPY_GE_200, NUMPY_GE_220, AxisError
+from dask.array.utils import allclose, assert_eq, same_keys
 
 if da._array_expr_enabled():
     pytest.skip("parametrize using unsupported functions", allow_module_level=True)
@@ -1237,6 +1237,92 @@ def test_cov():
         da.cov(d, ddof=1.5)
 
 
+@pytest.mark.skipif(
+    not NUMPY_GE_220, reason="fweights is not an kwarg prior to numpy 2.2"
+)
+def test_cov_fweights():
+    x1 = da.array([[0, 2], [1, 1], [2, 0]]).T
+    res1 = da.array([[1.0, -1.0], [-1.0, 1.0]])
+    x2 = da.array([0.0, 1.0, 2.0], ndmin=2)
+    frequencies = da.array([1, 4, 1])
+    x2_repeats = da.array([[0.0], [1.0], [1.0], [1.0], [1.0], [2.0]]).T
+    res2 = da.array([[0.4, -0.4], [-0.4, 0.4]])
+    unit_frequencies = np.ones(3, dtype=np.int_)
+
+    result = da.cov(x2, fweights=frequencies)
+    expected = np.cov(x2.compute(), fweights=frequencies.compute())
+    assert_eq(result, expected)
+
+    assert allclose(da.cov(x2, fweights=frequencies), da.cov(x2_repeats))
+    assert allclose(da.cov(x1, fweights=frequencies), res2)
+    assert allclose(da.cov(x1, fweights=unit_frequencies), res1)
+
+    f = da.ones((2, 3), dtype=np.int_)
+    with pytest.raises(RuntimeError):
+        da.cov(x1, fweights=f)
+
+    f = da.ones(2, dtype=np.int_)
+    with pytest.raises(RuntimeError):
+        da.cov(x1, fweights=f)
+
+
+@pytest.mark.skipif(
+    not NUMPY_GE_220, reason="aweights is not an kwarg prior to numpy 2.2"
+)
+def test_cov_aweights():
+    x1 = da.array([[0, 2], [1, 1], [2, 0]]).T
+    res1 = da.array([[1.0, -1.0], [-1.0, 1.0]])
+
+    # Test basic functionality with aweights
+    aweights = da.array([0.5, 2.0, 0.5])  # Analytical weights
+    unit_aweights = np.ones(3, dtype=np.float64)
+
+    # With unit weights, should match unweighted result
+    assert allclose(da.cov(x1, aweights=unit_aweights), res1)
+
+    # Test that aweights affects the covariance calculation
+    weighted_result = da.cov(x1, aweights=aweights)
+    unweighted_result = da.cov(x1)
+    # Results should be different when using non-unit weights
+    assert not allclose(weighted_result, unweighted_result)
+
+    # Test with different weight patterns
+    equal_weights = da.array([1.0, 1.0, 1.0])
+    assert allclose(da.cov(x1, aweights=equal_weights), da.cov(x1))
+
+    # Multidimensional aweights should raise RuntimeError
+    multidim_weights = da.ones((2, 3), dtype=np.float64)
+    with pytest.raises(RuntimeError):
+        da.cov(x1, aweights=multidim_weights)
+
+    # Wrong length aweights should raise RuntimeError
+    wrong_length_weights = da.ones(2, dtype=np.float64)
+    with pytest.raises(RuntimeError):
+        da.cov(x1, aweights=wrong_length_weights)
+
+
+@pytest.mark.skipif(
+    not NUMPY_GE_220, reason="fweights and aweights are not kwargs prior to numpy 2.2"
+)
+def test_cov_fweights_aweights_combined():
+    x1 = da.array([[0, 2], [1, 1], [2, 0]]).T
+
+    # Test combining both frequency and analytical weights
+    fweights = da.array([1, 2, 1])  # Frequency weights (integers)
+    aweights = da.array([0.5, 1.0, 2.0])  # Analytical weights (floats)
+
+    # Should work without error when both are provided
+    result = da.cov(x1, fweights=fweights, aweights=aweights)
+    assert result.shape == (2, 2)
+
+    # Result should be different from using either weight alone
+    result_f_only = da.cov(x1, fweights=fweights)
+    result_a_only = da.cov(x1, aweights=aweights)
+
+    assert not allclose(result, result_f_only)
+    assert not allclose(result, result_a_only)
+
+
 def test_corrcoef():
     x = np.arange(56).reshape((7, 8))
     d = da.from_array(x, chunks=(4, 4))
@@ -1251,6 +1337,13 @@ def test_corrcoef():
     assert_eq(da.corrcoef(d, e), np.corrcoef(x, y))
     assert_eq(da.corrcoef(e, d), np.corrcoef(y, x))
 
+    d = da.array([[1, 2]])
+    x = np.array([[1, 2]])
+
+    if NUMPY_GE_220:
+        with pytest.warns(RuntimeWarning):
+            assert_eq(da.corrcoef(d, rowvar=False), np.corrcoef(x, rowvar=False))
+
 
 def test_round():
     x = np.random.default_rng().random(10)
@@ -1598,6 +1691,16 @@ def test_take():
     assert same_keys(da.take(a, [3, 4, 5], axis=-1), da.take(a, [3, 4, 5], axis=-1))
 
 
+def test_take_large():
+    a = da.arange(1_000_000_000_000, chunks=(200_000_000,), dtype="int64")
+
+    x = np.arange(20, dtype="int64")
+    assert_eq(da.take(a, x, axis=0), x)
+
+    x = np.arange(50, 300, dtype="int64")
+    assert_eq(da.take(a, x, axis=0), x)
+
+
 def test_take_dask_from_numpy():
     x = np.arange(5).astype("f8")
     y = da.from_array(np.array([1, 2, 3, 3, 2, 1]), chunks=3)
@@ -1712,6 +1815,13 @@ def test_choose():
     assert_eq(index_dask.choose([0, d]), index_numpy.choose([0, x]))
     assert_eq(index_dask.choose([-d, d]), index_numpy.choose([-x, x]))
 
+    indices_np = np.array([0, 0, 0, 0])
+    choices_np = (np.array([10.0, 20.0, 30.0, 40.0]),)
+    indices_da = da.from_array(indices_np, chunks=(2,))
+    choices_da = da.from_array(choices_np, chunks=(1, 2))
+
+    assert_eq(np.choose(indices_np, choices_np), da.choose(indices_da, choices_da))
+
 
 def test_piecewise():
     rng = np.random.default_rng(1337)
