@@ -23,11 +23,6 @@ try:
     from dask.bag.core import (
         Bag,
         Item,
-    )
-    from dask.bag.core import bag_map as map
-    from dask.bag.core import bag_range as range
-    from dask.bag.core import bag_zip as zip
-    from dask.bag.core import (
         concat,
         from_delayed,
         from_sequence,
@@ -35,6 +30,9 @@ try:
         map_partitions,
         to_textfiles,
     )
+    from dask.bag.core import bag_map as map
+    from dask.bag.core import bag_range as range
+    from dask.bag.core import bag_zip as zip
     from dask.bag.text import read_text
     from dask.bag.utils import assert_eq
     from dask.base import compute
@@ -45,4 +43,4 @@ except ImportError as e:
         "  conda install dask               # either conda install\n"
         '  python -m pip install "dask[bag]" --upgrade  # or python -m pip install'
     )
-    raise ImportError(str(e) + "\n\n" + msg) from e
+    raise ImportError(f"{e}\n\n{msg}") from e
